package users

import (
	"catface/app/global/consts"
	"catface/app/http/controller/web"
	"catface/app/http/validator/core/data_transfer"
	"catface/app/utils/response"

	"github.com/gin-gonic/gin"
)

type WeixinLogin struct {
	Code       string `form:"code" json:"code"`
	UserName   string `form:"user_name" json:"user_name"`
	UserAvatar string `form:"user_avatar" json:"user_avatar"` // INFO 本地缓存，不确定 url 的类型。
}

func (w WeixinLogin) CheckParams(context *gin.Context) {
	//1.先按照验证器提供的基本语法，基本可以校验90%以上的不合格参数
	if err := context.ShouldBind(&w); err != nil {
		response.ValidatorError(context, err)
		return
	}

	// INFO 该函数主要是将本结构体的字段（成员）按照 consts.ValidatorPrefix+ json标签对应的 键 => 值 形式绑定在上下文，便于下一步（控制器）可以直接通过 context.Get(键) 获取相关值
	extraAddBindDataContext := data_transfer.DataAddContext(w, consts.ValidatorPrefix, context)
	if extraAddBindDataContext == nil {
		response.ErrorSystem(context, "userWeixinLogin表单验证器json化失败", "")
	} else {
		// 验证完成，调用控制器,并将验证器成员(字段)递给控制器，保持上下文数据一致性
		(&web.Users{}).WeixinLogin(extraAddBindDataContext)
	}
}
